<?php

/* 
 * dbquery.inc - the script performing the database query and creating the HTML output for it
 *
 * Copyright (c) by Andreas S. Krebs (andreas.krebs@web.de)
 *
 * this script expects in the variable $query the WHERE clause of the SQL query to perform
 * and returns in $entries_found the number of entries found in the database.
 *
 */

require("config.inc");

$conn=pg_connect("host=$DBHOST user=$DBUSER dbname=$DBNAME");
if(!$conn)
{
  echo("<H1>Failed to open the database $DB_NAME at $DB_HOST for $DB_USER</H1>");
}
else
{
  // Execute query (we also get the oid, also we don't need it yet)
  if($sortby == "")
    $sortby="artist ASC,title ASC,album ASC";

  $sortdir="ASC";
  $isortdir="DESC";
  if(stristr($sortby, "ASC") === false)
  {
    $sortdir="DESC";
    $isortdir="ASC";
  }
   
  $result=pg_exec($conn,"SELECT * FROM songs WHERE $query ORDER BY $sortby;");

  $entries_found=pg_numrows($result);
  
  if($entries_found > 0)
  {
    // Create result table header

    echo("
<CENTER>
<TABLE BORDER=1 CELLPADDING=4 CELLSPACING=2>
<TR>
");

    if($entries_found > 1)
    {
      $newquery=$QUERY_STRING;
      $newquery=ereg_replace("sortby=.*&", "", $newquery);
      $newquery=ereg_replace("&sortby=.*", "", $newquery);  // in case we are at the end of the query
      $newquery=$SCRIPT_NAME . "?" . $newquery . "&sortby=";

      $isortby=ereg_replace($sortdir, $isortdir, $sortby);
      $indirquery=$newquery . rawurlencode($isortby);

      $sortimg=ereg_replace("ASC", "images/down.png", $isortdir);
      $sortimg=ereg_replace("DESC", "images/up.png", $sortimg);
 
      echo("
  <TD WIDTH=1% ALIGN=CENTER><A HREF=\"$indirquery\"><IMG SRC=\"$sortimg\" BORDER=0></A></TD>
  <TD ALIGN=CENTER WIDTH=20%><B><A HREF=\"$newquery"."artist+$sortdir%2Ctitle+$sortdir%2Calbum+$sortdir\">Artist:</A></B></TD>
  <TD ALIGN=CENTER WIDTH=30%><B><A HREF=\"$newquery"."title+$sortdir%2Cartist+$sortdir%2Calbum+$sortdir\">Title:</A></B></TD>
  <TD ALIGN=CENTER WIDTH=20%><B><A HREF=\"$newquery"."album+$sortdir%2Cartist+$sortdir%2Ctitle+$sortdir\">Album:</A></B></TD>
");
    }
    else  // no need for sorting links, cause we have only one entry 
    {
      echo("
  <TD WIDTH=1%></TD>
  <TD ALIGN=CENTER WIDTH=20%><B>Artist:</B></TD>
  <TD ALIGN=CENTER WIDTH=30%><B>Title:</B></TD>
  <TD ALIGN=CENTER WIDTH=20%><B>Album:</B></TD>
");
    }

    echo("
  <TD ALIGN=CENTER WIDTH=5%><B>Length:</B></TD>
  <TD ALIGN=CENTER WIDTH=5%><B>kbps:</B></TD>
  <TD ALIGN=CENTER WIDTH=5%><B>Size:</B></TD>
  <TD ALIGN=CENTER WIDTH=1%><B>File:</B></TD>
</TR>
<TR></TR>
");

    // Get results from database

    $rows=0;
    while($rows < pg_numrows($result))
    {
      $song=pg_fetch_object($result, $rows);

      // Convert the seconds to M:SS format
      $secs=$song->length % 60;
      $min=($song->length - $secs)/60;
      $s1=$secs%10;
      $s10=($secs-$s1)/10;

      // Encode URLs
      $url=rawurlencode($song->file);
      $url=$LINKROOT . $song->file;

      $song->fileurl=rawurlencode($MP3ROOT . $song->file);
      $uartist=rawurlencode($song->artist);
      $utitle=rawurlencode($song->title);
      $ualbum=rawurlencode($song->album);

      // Let's put a few . into the file size ;-)
      $fsize=substr($song->filesize, -3);
      $t=substr($song->filesize, 0, -3);
      while(strlen($t) > 0)
      {
        $fsize=substr($t, -3) . ".$fsize";
        $t=substr($t, 0, -3);
      }

      // convert html special chars where needed
      $song->$artist=htmlspecialchars($song->$artist);
      $song->title=htmlspecialchars($song->title);
      $song->album=htmlspecialchars($song->album);

      // create a table row for this entry 
      echo("
<TR>
  <TD><A HREF=\"play.php?file=$song->fileurl\" TARGET=\"playing\" ALT=\"[Play]\"><IMG SRC=\"images/play.png\" BORDER=0></A></TD>
  <TD><A HREF=\"search.php?artist=$uartist\">$song->artist</A></TD>
  <TD><A HREF=\"search.php?title=$utitle\">$song->title</A></TD>
  <TD><A HREF=\"search.php?album=$ualbum\">$song->album</A></TD>
  <TD ALIGN=RIGHT>$min:$s10$s1</TD>
  <TD ALIGN=RIGHT>$song->bitrate</TD>
  <TD ALIGN=RIGHT>$fsize</TD>
  <TD><A HREF=\"$url\" ALT=\"[Download]\"><IMG SRC=\"images/download.png\" BORDER=0></A></TD>
</TR>
      ");

      $rows++;
    }

    echo("</TABLE>");
  }

  pg_close($conn);
}

?>

