#!/usr/bin/perl
#
# addplaylist.pl - add playlist files to your database
#
# Copyright (c) by Andreas S. Krebs (andreas.krebs@web.de)
#
# this script adds playlists in m3u format to the muwed database
# 
# NOTE:
# all songs of the playlist have to exist in the database under
# the name used in the playlist or the insert will fail
#

use Pg;

$DBNAME="muwed";
$DBUSER="postgres";

chomp($BASEDIR=`pwd`);
$BASEDIR.="/";

# try to connect to the database
$conn=Pg::connectdb("dbname=$DBNAME user=$DBUSER");
( PGRES_CONNECTION_OK eq $conn->status )
    and print "Pg::connectdb ........... ok\n"
    or  die   "Pg::connectdb ........... not ok: ", $conn->errorMessage;

foreach $file (@ARGV)
{
  processFile($file);
}

1;

sub processFile
{
  local($file)=shift(@_);
  local($title);
  $file=~s/^.\///;

  chomp($title=`basename $file`);
  $title=~ s/\..*$//g;

  print "processing: $file\n";    
  @songs=&getSongs($file);

  if($#songs >= 0)
  {
    #let's create the playlist entry

    $file=&db_escape($file);
    $title=&db_escape($title);
    &pg_exec("INSERT INTO playlists VALUES ($file, $title, NULL)");

    foreach(@songs)
    {
      $song=&db_escape($_);

      &pg_exec("INSERT INTO pl_entries SELECT p.id, s.id FROM playlists p, songs s WHERE p.file=$file AND s.file=$song");
    }
  }
}

sub pg_exec
{
  local($query)=shift(@_);
  local($result);

  print "$query\n";
  $result=$conn->exec($query);
  print $conn->errorMessage;
}

sub db_escape
{
  local($field)=shift(@_);

  $field=~ s/'/''/g;
#  $field=~ s/`/\\`/g;

  if($field eq "")
  {
    $field="NULL";
  }
  else
  {
    $field="'$field'";
  }

  return ($field);
}

sub getSongs
{
  local($filename)=shift(@_);
  local(@songs)=();

  unless(open(FH, $filename))
  {
     print STDERR "Can't open $filename: $!\n";
     return @songs;
  }
  
  while(<FH>)
  {
    chomp;
  
    s/^$BASEDIR//g;
    $t=&removeSpaces($_);
    
    if($t ne "")
    {
      @songs=(@songs, $t);
    }
  }

  close(FH);

  return @songs;
}

sub removeSpaces
{
  local($txt)=shift(@_);

  while(substr($txt, 0, 1) eq " " || substr($txt, 0, 1) eq "\t")
  {
    $txt=substr($txt, 1);
  }

  while(substr($txt, -1, 1) eq " " || substr($txt, -1, 1) eq "\t")
  {
    $txt=substr($txt, 0, -1);
  }

  $txt=~s/"/\\"/g;

  return $txt;
}

